<p align="center">
  <img src="logo.png" width="420px" align="center" alt="bluemoss logo" />
  <h1 align="center">bluemoss</h1>
  <p align="center">
    ✨ <a href="https://github.com/LucaTabone/bluemoss">GitHub</a> ✨
    <br/>
    A simple way to scrape the web.
  </p>
</p>
